from setuptools import setup, find_packages

setup(
    name='smartfeedabcdefg',
    version='1.0.0',
    description='用于smartfeed和流量渠道自动化测试工具包',
    author='zhouyanhui',
    packages=find_packages(),
    install_requires=[
        # List your package's dependencies here
        # TODO
    ],
)
